import { ChangeEvent, useState } from "react"
import { Pagination, Search } from ".."
import Helper from "../../utils/helper"
import "./IconsList.component.scss"

interface IconsListProps {
  icons?: Array<IconResponse>
  onSearchChanged: Function
}

interface IconTileProps {
  icon: IconResponse
}

const IconTile = (props: IconTileProps): JSX.Element => {
  const { icon } = props

  return (
    <span
      className="c-IconTile d-inline-block mx-2 mb-3 border"
      onClick={() => {
        const iconLink = `http://localhost:8080/icon/${icon.group}/${icon.name}`
        navigator.clipboard.writeText(iconLink)
        // TODO: replace below line with a dispatcher to show notification
        // alert("Copied link to clipboard: " + iconLink)
      }}
    >
      <div className="c-IconTile__image text-center">
        <img
          className="h-100"
          src={`data:image/svg+xml;utf8,${icon.svg}`}
          alt="icon"
        />
      </div>
      <footer className="fw-bold text-nowrap overflow-hidden flex-center">
        {icon.name}
      </footer>
    </span>
  )
}

const IconsList = (props: IconsListProps): JSX.Element => {
  const { icons, onSearchChanged } = props
  const slices =
    icons &&
    icons.length > 0 &&
    Helper.generateSlices(icons.length, 100, "index")
  return (
    <div className="c-IconsList h-100 w-100 overflow-auto p-3">
      <div className="c-IconsList__header-pagination-search py-2 px-3 mb-3 border">
        <div className="row">
          <div className="col-2 d-flex align-items-center">
            <h6 className="mb-0">Icon Repository</h6>
          </div>
          <div className="col-7 flex-center">
            {slices && <Pagination data={slices} maxPillsToShow={5} />}
          </div>
          <div className="col-3">
            <Search
              classes="bg-white h-100"
              placeholder="Search by name, tags, description"
              onChange={(event: ChangeEvent<HTMLInputElement>) =>
                onSearchChanged(event.target.value)
              }
              data={
                icons
                  ? icons.map(
                      (icon): SearchItem => ({
                        label: icon.name,
                        data: icon,
                      }),
                    )
                  : []
              }
            />
          </div>
        </div>
      </div>
      <div className="c-IconsList__icon-tile-container py-2 px-3 border d-flex justify-content-between flex-wrap">
        {icons &&
          icons
            .slice(0, 100)
            .map((icon, index) => <IconTile key={index} icon={icon} />)}
      </div>
    </div>
  )
}

export default IconsList
