import { ChangeEvent, useState } from "react"
import "./DropDown.component.scss"

interface DropDownProps {
  context?: string
  id?: string
  label?: string
  onSelectionChanged: Function
  options: Array<Map<string, string | number>>
}

const DropDown = (props: DropDownProps): JSX.Element => {
  const { context, id, label, onSelectionChanged, options } = props
  const [value, setValue] = useState<string>()
  const onLocalChange = (e: ChangeEvent<HTMLSelectElement>) => {
    setValue(e.target.value)
    onSelectionChanged &&
      onSelectionChanged(
        {
          value: e.target.value,
          data: options.find(
            (o) => (o.get("name") || o.get("label")) === e.target.value,
          ),
        },
        context,
      )
  }
  return (
    <div className="c-DropDown w-100 mb-3">
      {label && (
        <label className="c-DropDown__label label" htmlFor={id}>
          {label}
        </label>
      )}
      <select
        id={id}
        className="c-DropDown__select form-component px-3 py-2 w-100"
        onChange={onLocalChange}
      >
        {options.map((option) => (
          <option value={option.get("name") || option.get("label")}>
            {option.get("label")}
          </option>
        ))}
      </select>
    </div>
  )
}

export default DropDown
