import { ChangeEvent, useState } from "react"
import "./TextInput.component.scss"

interface TextInputProps {
  classes?: string
  containerClasses?: string
  onBlur?: (event: ChangeEvent<HTMLInputElement>) => void
  onChange: (event: ChangeEvent<HTMLInputElement>) => void
  onFocus?: (event: ChangeEvent<HTMLInputElement>) => void
  placeholder?: string
  type?: string
}

const TextInput = (props: TextInputProps): JSX.Element => {
  const {
    classes,
    containerClasses,
    onBlur,
    onChange,
    onFocus,
    placeholder,
    type,
  } = props
  const [value, setValue] = useState<string | undefined>()
  const [focussed, setFocussed] = useState<boolean | undefined>(false)
  const onLocalChange = (event: ChangeEvent<HTMLInputElement>): void => {
    setValue(event.target.value)
    onChange && onChange(event)
  }
  return (
    <div
      className={`c-TextInput position-relative w-100${
        focussed ? " focussed border-bottom-0" : ""
      }${containerClasses ? " " + containerClasses : ""}`}
    >
      <input
        type={type || "text"}
        className={`c-TextInput__input w-100 h-100${
          classes ? " " + classes : ""
        }`}
        onChange={onLocalChange}
        onFocus={(...focusHandlerArgs) => {
          setFocussed(true)
          onFocus && onFocus(...focusHandlerArgs)
        }}
        onBlur={(...focusHandlerArgs) => {
          setFocussed(false)
          onBlur && onBlur(...focusHandlerArgs)
        }}
        placeholder={focussed ? "" : placeholder}
      />
      <button
        className={`c-TextInput__clear-button position-absolute end-0 top-0 d-flex flex-row
          justify-content-center align-items-center h-100 border-0 bg-transparent${
            value ? " has-value" : ""
          }${focussed ? " border-bottom-0" : ""}`}
      />
    </div>
  )
}

export default TextInput
