import { useState } from "react"
import { Icon, Search } from "../.."
import "./TreeList.component.scss"

interface TreeListProps {
  data: Array<TreeListData>
  firstExpanded?: boolean
  noSearch?: boolean
  title?: string
}

interface TreeListItemProps {
  hierarchyLevel: number
  data: TreeListData
  expanded: boolean | undefined
}

const generateRenders = (
  data: Array<TreeListData>,
  i: number,
  firstExpanded: boolean | undefined,
): JSX.Element | null => {
  return (
    data && (
      <ul className={`c-TreeList__list list-unstyled`}>
        {data.map((obj, index) => (
          <TreeListItem
            hierarchyLevel={i}
            data={obj}
            expanded={i === 0 && index === 0 && firstExpanded}
          />
        ))}
      </ul>
    )
  )
}

const TreeListItem = (props: TreeListItemProps): JSX.Element => {
  const { hierarchyLevel, data, expanded: preExpanded } = props
  const [expanded, setExpanded] = useState<boolean | undefined>(preExpanded)

  let children: JSX.Element | null = null
  if (data.children) {
    children = generateRenders(data.children, hierarchyLevel + 1, false)
  }
  return (
    <li className={`c-TreeListItem${!expanded ? " expanded" : ""}`}>
      <span
        className="d-inline-block py-2 w-100"
        style={{
          paddingLeft:
            hierarchyLevel > 0 ? 1.25 + 0.8 * hierarchyLevel + "rem" : 0,
        }}
        onClick={() => children && setExpanded(!expanded)}
      >
        {children && (
          <Icon
            containerClasses="me-1"
            src="http://localhost:8080/icon/md/MdKeyboardArrowRight"
          />
        )}
        {data.label}
      </span>
      {children}
    </li>
  )
}

const TreeList = (props: TreeListProps): JSX.Element => {
  const { data, firstExpanded, noSearch, title } = props
  const [filteredItems, setFilteredItems] = useState<
    Array<SearchItem> | undefined | null
  >()

  return (
    <div className="c-TreeList mx-1">
      {title && <strong className="d-block mb-3 mt-2">{title}</strong>}
      {!noSearch && (
        <Search
          data={data}
          onChange={(e, filteredItems) => setFilteredItems(filteredItems)}
        />
      )}
      {generateRenders(filteredItems || data, 0, firstExpanded)}
    </div>
  )
}

export default TreeList
