import { SelectionPill } from "../.."
import Helper from "../../../utils/helper"
import "./CategoryFilter.component.scss"

interface CategoryFilterProps {
  categoryGroups: Map<string, Map<string, Array<string>>>
  onCategorySelection: Function
}

const CategoryFilter = (props: CategoryFilterProps): JSX.Element => {
  const { categoryGroups, onCategorySelection } = props

  const categoryRenders = (
    categories: Map<string, Array<string>> | undefined,
  ) => {
    return (
      categories && (
        <div className="c-CategoryFilter__pill-container">
          {Array.from(categories.keys()).map((category) => (
            <SelectionPill
              classes="rounded me-2 mb-3"
              data={
                new Map<string, string | number | JSX.Element>([
                  ["label", category],
                ])
              }
              size="small"
              onClick={(data: BasicFilterConfig) =>
                onCategorySelection(data, category)
              }
            />
          ))}
        </div>
      )
    )
  }
  const groupRenders = Array.from(categoryGroups.keys()).map(
    (group: string) => {
      return (
        <div className="c-CategoryFilter__group">
          <label className="c-CategoryFilter__label label">
            {Helper.toCamelCase(group, " ", true)}
          </label>
          <div className="c-CategoryFilter__filters">
            {categoryRenders(categoryGroups.get(group))}
          </div>
        </div>
      )
    },
  )

  return <div className="c-CategoryFilter">{groupRenders}</div>
}

export default CategoryFilter
