import { useState } from "react"
import { AlphabetFilter, CategoryFilter, DropDown } from "../.."
import Helper from "../../../utils/helper"
import "./Filters.component.scss"

const Filters = (props: FiltersProps): JSX.Element => {
  const { config, data, initialFilters, onFilterChange } = props
  const [filters, setFilters] = useState<FilterState | undefined>(
    initialFilters,
  )
  const total = data && data.length

  const countOptions = Helper.generateSlices(
    total || 0,
    config.count || 0,
    "range",
  )

  const onLocalFilterChange = (
    data: BasicFilterType | undefined,
    type: string,
  ): void => {
    const filterClone = filters ? { ...filters } : {}
    const existing = filterClone[type as keyof FilterState]
    if (
      existing &&
      type !== "count" &&
      data &&
      type === "alphabet" &&
      "value" in existing &&
      "value" in data &&
      existing.value === data.value
    ) {
      filterClone[type as keyof FilterState] = undefined
    } else {
      filterClone[type as keyof FilterState] = data
    }
    setFilters(filterClone)
    onFilterChange && onFilterChange(filterClone)
  }

  return (
    <div className="c-Filters p-3 h-100 overflow-auto">
      <h4>Filters</h4>
      {"count" in config && (
        <DropDown
          context="count"
          id="icon-range-selector"
          label="Select a range"
          options={countOptions}
          onSelectionChanged={(data: BasicFilterConfig) => {
            onLocalFilterChange(data, "count")
          }}
        />
      )}
      {config.alphabet && (
        <AlphabetFilter onSelectionChanged={onLocalFilterChange} />
      )}
      {"categories" in config && (
        <CategoryFilter
          categoryGroups={Helper.generateCategories(data, config.categories)}
          onCategorySelection={(data: BasicFilterConfig, category: string) => {
            const categories: BasicFilterType =
              filters && filters.categories ? filters.categories : new Map()
            "set" in categories && categories.set(category, data)
            onLocalFilterChange(categories, "categories")
          }}
        />
      )}
    </div>
  )
}

export default Filters
