import { ChangeEvent, useState } from "react"
import { Button, Icon, TextInput } from "../.."
import Helper from "../../../utils/helper"
import "./Search.component.scss"

interface BaseSearchProps {
  classes?: string
  data: Array<SearchItem>
  placeholder?: string
}

interface SearchPropsWithOnClick extends BaseSearchProps {
  onChange: (
    event: ChangeEvent<HTMLInputElement>,
    filteredItems: Array<SearchItem> | null,
  ) => void
}

interface SearchPropsWithPopperPrevented extends BaseSearchProps {
  showPopUp: boolean
}

type SearchProps = SearchPropsWithOnClick | SearchPropsWithPopperPrevented

const Search = (props: SearchProps): JSX.Element => {
  const { classes, data, placeholder } = props
  const onChange = "onChange" in props && props.onChange
  const showPopUp = "showPopUp" in props && props.showPopUp

  const [filteredItems, setFilteredItems] = useState<
    Array<SearchItem> | undefined
  >()

  const [focusClass, setFocusClass] = useState<string | undefined>("")

  const onLocalChange: (event: ChangeEvent<HTMLInputElement>) => void = (
    event,
  ) => {
    if (showPopUp) {
      const filteredItems = Helper.recrusiveFilter(
        data,
        event.target.value,
        false,
        ["label"],
      )
      setFilteredItems(filteredItems)
      onChange && onChange(event, filteredItems)
    } else {
      onChange && onChange(event, null)
    }
  }

  const filteredItemsRenders =
    filteredItems &&
    filteredItems.map((item: SearchItem) => {
      return <div></div>
    })

  return (
    <div
      className={`c-Search d-flex w-100 position-relative ${focusClass}${
        classes ? " " + classes : ""
      }`}
    >
      <TextInput
        containerClasses="form-component"
        classes="c-Search__input p-1 bg-transparent border-0"
        onBlur={() => setFocusClass("")}
        onChange={onLocalChange}
        onFocus={() => setFocusClass("focussed")}
        placeholder={placeholder || "Search"}
        type="text"
      />
      <Button
        content={<Icon src="http://localhost:8080/icon/ai/AiOutlineSearch" />}
        classes={`search-button bg-transparent form-component${
          focusClass ? " border-bottom-0" : ""
        }`}
      />
      {(!onChange || showPopUp) && (
        <div
          className={`c-Search__search-results p-3 position-absolute top-100 start-0 w-100 bg-white border${
            focusClass ? "" : " h-0 overflow-hidden"
          }${filteredItemsRenders ? "" : " flex-center"}`}
          onClick={(e) => e.stopPropagation()}
        >
          {filteredItemsRenders || <i>Type to view results here</i>}
        </div>
      )}
    </div>
  )
}

export default Search
