import { useEffect, useState } from "react"
import { Filters } from "../../components"
import Footer from "../../components/Footer"
import Main from "../../components/Main"
import Header from "../../components/Header"
import IconsList from "../../components/IconsList"
import Network from "../../utils/network"
import Helper from "../../utils/helper"
import "./Icons.page.scss"

interface IconsProps {}

const fetchData = async (setIcons: Function) => {
  const response: { status: number; body: Array<IconResponse> } =
    await Network.getStatic("/icons", null, null)
  setIcons(response.body)
}

const Icons = (props: IconsProps): JSX.Element => {
  const [icons, setIcons] = useState<Array<IconResponse> | undefined>()
  const [searchText, setSearchText] = useState<string | undefined>()
  const [filteredIcons, setFilteredIcons] = useState<
    Array<IconResponse> | undefined
  >()
  const [filters, setFilters] = useState<FilterState | undefined>({
    count: {
      value: "1to1000",
      data: new Map<string, number | string>([
        ["startIndex", 0],
        ["endIndex", 999],
      ]),
    },
  })

  useEffect(() => {
    !icons && fetchData(setIcons)
  }, [icons])

  useEffect(() => {
    if (icons) {
      let finalFilteredIconList: Array<IconResponse> | undefined = icons
      if (searchText) {
        finalFilteredIconList = Helper.recrusiveFilter(
          finalFilteredIconList,
          searchText,
          false,
          ["name"],
        )
      }
      if (filters && finalFilteredIconList) {
        const countFilter =
          filters.count && "data" in filters.count && filters.count.data
        if (countFilter) {
          finalFilteredIconList = finalFilteredIconList.slice(
            countFilter.get("startIndex") as number,
            countFilter.get("endIndex") as number,
          )
        }

        const alphabet =
          filters.alphabet &&
          "value" in filters.alphabet &&
          filters.alphabet.value
        if (alphabet) {
          finalFilteredIconList = finalFilteredIconList.filter((icon) =>
            icon.name.toLowerCase().startsWith(alphabet.toLowerCase()),
          )
        }

        const categories = filters.categories && filters.categories

        if (categories) {
          Array.from(
            (categories as Map<string, BasicFilterConfig>).keys(),
          ).forEach((category) => {
            finalFilteredIconList = finalFilteredIconList?.filter((icon) => {
              return icon.group === category
            })
          })
        }
      }
      setFilteredIcons(finalFilteredIconList)
    }
  }, [filters, icons, searchText])

  return (
    <div className="c-Icons vh-100 d-flex flex-column">
      <Header />
      <Main
        drawerContent={
          <Filters
            config={{ count: 1000, alphabet: true, categories: ["group"] }}
            data={icons}
            initialFilters={filters}
            onFilterChange={setFilters}
          />
        }
        // mainContent={<IconsList icons={filteredIcons || icons} />}
        mainContent={
          <IconsList icons={filteredIcons} onSearchChanged={setSearchText} />
        }
      />
      <Footer />
    </div>
  )
}

export default Icons
