class Helper {
  static populateComponentsInRoutes(routes: RouteConfig[], components: any) {
    routes &&
      routes.forEach((route) => {
        const Component: JSX.ElementType =
          components[route.element as keyof object]
        route.element = <Component />
        if (route.children) {
          Helper.populateComponentsInRoutes(route.children, components)
        }
      })
  }

  static recrusiveFilter(
    data: Array<any>,
    filter: string,
    matchCase?: boolean,
    searchProps?: Array<string>,
  ) {
    if (!filter || !data || data.length === 0) {
      return data
    }
    if (!searchProps || searchProps.length === 0) {
      searchProps = ["label"]
    }
    const dataClone = JSON.parse(JSON.stringify(data))
    const filteredItems = dataClone.filter((obj: any) => {
      return (
        searchProps &&
        searchProps.reduce((acc, prop) => {
          let isMatch =
            obj[prop] &&
            (matchCase
              ? obj[prop].indexOf(filter) > -1
              : obj[prop].toLowerCase().indexOf(filter.toLowerCase()) > -1)
          if (obj.children) {
            obj.children = Helper.recrusiveFilter(
              obj.children,
              filter,
              matchCase,
            )
            isMatch = isMatch || obj.children.length > 0
          }
          return acc || isMatch
        }, false)
      )
    })
    return filteredItems
  }

  static generateSlices(
    count: number,
    sliceLength: number,
    labelFormat: string,
  ) {
    let i = 0,
      j = 0
    const slices = []
    while (i < count) {
      let addUp = sliceLength
      if (i + sliceLength > count) {
        addUp = count % sliceLength
      }
      const label =
        labelFormat === "range" ? i + 1 + " - " + (i + addUp) : "" + (j + 1)
      slices.push(
        new Map<string, string | number>([
          ["label", label],
          ["name", label.replace(/ /g, "").replace(/-/g, "to")],
          ["sliceIndex", j],
          ["startIndex", i],
          ["endIndex", i + addUp - 1],
        ]),
      )
      i += sliceLength
      j++
    }
    return slices
  }

  static aggregate(data: any, aggregator: string): Map<string, Array<string>> {
    let aggregated: Map<string, Array<string>> = new Map()
    data.forEach((item: any) => {
      const key = item[aggregator]
      let aggregatedArray: Array<string> | undefined = aggregated.get(key)
      if (!aggregatedArray) {
        aggregatedArray = []
        aggregated.set(key, aggregatedArray)
      }
      aggregatedArray.push(item)
    })
    return aggregated
  }

  static generateCategories(
    data: any,
    categories: Array<string> | undefined,
  ): Map<string, Map<string, Array<string>>> {
    const groups: Map<string, Map<string, Array<string>>> = new Map()
    if (categories && data) {
      categories.forEach((key) => {
        let group: Map<string, Array<string>> = Helper.aggregate(data, key)
        groups.set(key, group)
      })
    }
    return groups
  }

  static toCamelCase(str: string, separater: string, includeFirst: boolean) {
    const strParts = str.split(separater || " ")
    return strParts
      .map((part, i) =>
        i === 0 && includeFirst
          ? part.charAt(0).toUpperCase() + part.slice(1)
          : part,
      )
      .join("")
  }
}

export default Helper
